<template>
  <div :class="{ 'has-logo': showLogo }" :style="{ backgroundColor: variables.menuBackground }">
    <logo v-if="showLogo" :collapse="isCollapse" />
    <el-scrollbar :class="sideTheme" wrap-class="scrollbar-wrapper">
      <el-menu
        :default-active="activeMenu"
        :collapse="isCollapse"
        :background-color="menuColors.baseMenuBackground"
        :text-color="menuColors.baseMenuColor"
        :unique-opened="true"
        :active-text-color="menuColors.baseMenuLightColor"
        :collapse-transition="false"
        mode="vertical"
      >
        <sidebar-item v-for="(route, index) in sidebarRouters" :key="route.path + index" :item="route" :base-path="route.path" />
      </el-menu>
    </el-scrollbar>
  </div>
</template>

<script setup>
import Logo from "./Logo";
import SidebarItem from "./SidebarItem";
import variables from "@/assets/styles/variables.module.scss";
import useAppStore from "@/store/modules/app";
import useMenuStore from "@/store/modules/menu"; //菜单
import useSettingsStore from "@/store/modules/settings";
import usePermissionStore from "@/store/modules/permission";

const route = useRoute();
const appStore = useAppStore();
const menuStore = useMenuStore();
const settingsStore = useSettingsStore();
const permissionStore = usePermissionStore();
const sidebarRouters = computed(() => {
  return deepFilter(permissionStore.sidebarRouters);
});
const showLogo = computed(() => settingsStore.sidebarLogo);
const sideTheme = computed(() => settingsStore.sideTheme);
const menuColors = computed(() => menuStore.menuColors);
const theme = computed(() => settingsStore.theme);
const isCollapse = computed(() => {
  return !appStore.sidebar.opened;
});

const activeMenu = computed(() => {
  const { meta, path } = route;
  // if set path, the sidebar will highlight the path you set
  if (meta.activeMenu) {
    return meta.activeMenu;
  }
  return path;
});

const deepFilter = (arr) => {
  return arr.filter((item) => {
    if (item.children) {
      item.children = deepFilter(item.children);
    }
    if (!item.hidden) {
      return true;
    }
  });
};
</script>
